Affected by GO-2022-0368
and 5 other vulnerabilities
GO-2022-0368: Improper random number generation in github.com/coredns/coredns
GO-2024-3130: CoreDNS vulnerable to TuDoor Attacks in github.com/coredns/coredns
GO-2025-3743: CoreDNS Vulnerable to DoQ Memory Exhaustion via Stream Amplification in github.com/coredns/coredns
GO-2026-4289: CoreDNS gRPC/HTTPS/HTTP3 servers lack resource limits, enabling DoS via unbounded connections and oversized messages in github.com/coredns/coredns
GO-2026-4630: CoreDNS ACL Bypass in github.com/coredns/coredns
GO-2026-4635: CoreDNS Loop Detection Denial of Service Vulnerability in github.com/coredns/coredns
type Replacer interface {
Replace(string) string Set(key, value string)
}
Replacer is a type which can replace placeholder
substrings in a string with actual values from a
dns.Msg and responseRecorder. Always use
NewReplacer to get one of these.
New makes a new replacer based on r and rr.
Do not create a new replacer until r and rr have all
the needed values, because this function copies those
values into the replacer. rr may be nil if it is not
available. emptyValue should be the string that is used
in place of empty string (can still be empty string).